@@ -1,20 +1,20 @@
 
 #include <kapp.h>
+#include <kstddirs.h>
 #include <qaccel.h>
-#include <qmsgbox.h>
+#include <qmessagebox.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <kstatusbar.h>
 #include <ktoolbar.h>
-#include <ktopwidget.h>
+#include <ktmainwindow.h>
 #include <kmenubar.h>
+#include <khelpmenu.h>
+#include <kconfig.h>
 #include <klocale.h>
 
 // sound support
-extern "C" {
-#include <mediatool.h>
-}
-#include <kaudio.h>
+#include <kaudioplayer.h>
 
 #include "kfixedtopwidget.h"
 #include "toplevel.h"
@@ -23,6 +23,7 @@ extern "C" {
 #include "toplevel.moc"
 
 #include <X11/Xlib.h>
+#include <klocale.h>
 
 #define SB_SCORE	1
 #define SB_LEVEL	2
@@ -72,7 +73,7 @@ const char *soundDefaults[] =
 
 KAstTopLevel::KAstTopLevel() : KFixedTopWidget()
 {
-    setCaption( kapp->getCaption() );
+    setCaption( kapp->caption() );
 
     QWidget *mainWin = new QWidget( this );
 
@@ -95,7 +96,7 @@ KAstTopLevel::KAstTopLevel() : KFixedTopWidget()
     hb->addSpacing( 10 );
 
     QLabel *label;
-    label = new QLabel( klocale->translate("Score"), mainWin );
+    label = new QLabel( i18n("Score"), mainWin );
     label->setFont( labelFont );
     label->setPalette( pal );
     label->setFixedWidth( label->sizeHint().width() );
@@ -109,7 +110,7 @@ KAstTopLevel::KAstTopLevel() : KFixedTopWidget()
     hb->addWidget( scoreLCD );
     hb->addStretch( 10 );
 
-    label = new QLabel( klocale->translate("Level"), mainWin );
+    label = new QLabel( i18n("Level"), mainWin );
     label->setFont( labelFont );
     label->setPalette( pal );
     label->setFixedWidth( label->sizeHint().width() );
@@ -123,7 +124,7 @@ KAstTopLevel::KAstTopLevel() : KFixedTopWidget()
     hb->addWidget( levelLCD );
     hb->addStretch( 10 );
 
-    label = new QLabel( klocale->translate("Ships"), mainWin );
+    label = new QLabel( i18n("Ships"), mainWin );
     label->setFont( labelFont );
     label->setFixedWidth( label->sizeHint().width() );
     label->setPalette( pal );
@@ -158,16 +159,10 @@ KAstTopLevel::KAstTopLevel() : KFixedTopWidget()
     setFocus();
 
     readSettings();
-
-    kas = new KAudio;
-
-    if ( kas->serverStatus() )
-	sound = false;
 }
 
 KAstTopLevel::~KAstTopLevel()
 {
-    delete kas;
 }
 
 void KAstTopLevel::createMenuBar()
@@ -177,25 +172,25 @@ void KAstTopLevel::createMenuBar()
 
     QPopupMenu *fileMenu = new QPopupMenu;
     CHECK_PTR( fileMenu );
-    fileMenu->insertItem( klocale->translate( "&New Game" ), this,
+    fileMenu->insertItem( i18n( "&New Game" ), this,
 	SLOT(slotNewGame()), CTRL+Key_N );
     fileMenu->insertSeparator( );
-    fileMenu->insertItem( klocale->translate( "&Quit" ), this, SLOT(slotQuit()),
+    fileMenu->insertItem( i18n( "&Quit" ), this, SLOT(slotQuit()),
 	CTRL+Key_Q );
 
-    QPopupMenu *help = kapp->getHelpMenu(true, QString(i18n("Asteroids"))
-                                         + " " + KASTEROIDS_VERSION
-                                         + i18n("\n\nby Martin R. Jones")
-                                         + " (mjones@kde.org)"); 
+    KHelpMenu *help = new KHelpMenu(this,
+                                    i18n("Asteroids %1\n\n"
+                                         "by Martin R. Jones (mjones@kde.org)")
+                                    .arg(KASTEROIDS_VERSION)); 
 
-    menu->insertItem( klocale->translate( "&File" ), fileMenu );
+    menu->insertItem( i18n( "&File" ), fileMenu );
     menu->insertSeparator();
-    menu->insertItem( klocale->translate( "&Help" ), help );
+    menu->insertItem( i18n( "&Help" ), help->menu() );
 }
 
 void KAstTopLevel::readSettings()
 {
-    KConfig *config = KApplication::getKApplication()->getConfig();
+    KConfig *config = kapp->config();
     config->setGroup( "Sounds" );
 
     QString qs;
@@ -204,9 +199,11 @@ void KAstTopLevel::readSettings()
     {
 	qs = config->readEntry( soundEvents[i] );
 	if ( !qs.isEmpty() )
-	    soundDict.insert( soundEvents[i], qs );
+	    soundDict.insert( soundEvents[i], 
+		new QString( locate("appdata", qs)) );
 	else
-	    soundDict.insert( soundEvents[i], soundDefaults[i] );
+	    soundDict.insert( soundEvents[i], 
+		new QString( locate("appdata", soundDefaults[i])) );
     }
 
     qs = config->readEntry( "PlaySounds" );
@@ -218,11 +215,9 @@ void KAstTopLevel::readSettings()
 
 void KAstTopLevel::playSound( const char *snd )
 {
-    kas->stop();
-    QString filename = kapp->kde_datadir().copy();
-    filename += "/kasteroids/";
-    filename += soundDict[ snd ];
-    kas->play( filename );
+    QString *filename = soundDict[ snd ];
+    if (filename)
+        KAudioPlayer::play( *filename );
 }
 
 void KAstTopLevel::keyPressEvent( QKeyEvent *event )
@@ -314,7 +309,7 @@ void KAstTopLevel::slotNewGame()
     view->newGame();
     view->setRockSpeed( levels[0].rockSpeed );
     view->addRocks( levels[0].nrocks );
-    view->showText( klocale->translate( "Press Enter to launch." ), yellow );
+    view->showText( i18n( "Press Enter to launch." ), yellow );
     waitShip = true;
 }
 
@@ -333,12 +328,14 @@ void KAstTopLevel::slotShipKilled()
     if ( shipsRemain )
     {
 	waitShip = true;
-	view->showText( klocale->translate( "Ship Destroyed.  Press Enter to launch."), yellow );
+	view->showText( i18n( "Ship Destroyed.  Press Enter to launch."), yellow );
     }
     else
     {
-	QMessageBox::message(klocale->translate("KAsteriods"),
-	    klocale->translate("Game Over!"));
+	QMessageBox::information(0,
+	    i18n("Asteriods"),
+	    i18n("Game Over!"),
+	    i18n("OK"));
 	view->endGame();
     }
 }
@@ -376,4 +373,3 @@ void KAstTopLevel::slotRocksRemoved()
 
     levelLCD->display( level );
 }
-
