@@ -4,16 +4,14 @@
 
 #include <kstatusbar.h>
 #include <ktoolbar.h>
-#include <ktopwidget.h>
-#include <qlcdnum.h>
+#include <ktmainwindow.h>
+#include <qlcdnumber.h>
 #include <qdict.h>
 #include <kmenubar.h>
 
 #include "kfixedtopwidget.h"
 #include "view.h"
 
-class KAudio;
-
 class KAstTopLevel : public KFixedTopWidget
 {
     Q_OBJECT
@@ -49,8 +47,7 @@ private:
     QLCDNumber *shipsLCD;
 
     bool   sound;
-    KAudio *kas;
-    QDict<char> soundDict;
+    QDict<QString> soundDict;
 
     // waiting for user to press Enter to launch a ship
     bool waitShip;
