@@ -5,12 +5,13 @@
 #include <qevent.h>
 #include <qkeycode.h>
 #include <qlistbox.h>
-#include <qpushbt.h>
-#include <qlined.h>
+#include <qpushbutton.h>
+#include <qlineedit.h>
 #include <qvalidator.h>
-#include <kmsgbox.h>
 #include <kapp.h>
-#include <kslider.h>
+#include <klocale.h>
+#include <qmessagebox.h>
+#include <kglobal.h>
 #include <kiconloader.h>
 
 #include <ctype.h>
@@ -24,6 +25,7 @@
 #include "gameenddlg.h"
 #include "scoredlg.h"
 #include "gameboard.h"
+#include <klocale.h>
 #include "gameboard.moc"
 
 
@@ -36,8 +38,6 @@ GameBoard::GameBoard( QWidget *parent )
     QColorGroup cg( white, black, green.light(), green.dark(), green, green.dark(75), green.dark() );
     QPalette palette( cg, cg, cg );
 
-    KIconLoader *iconloader = KApplication::getKApplication()->getIconLoader();
-
     neutralPlayer = Player::createNeutralPlayer();
     map = new Map;
 
@@ -66,7 +66,7 @@ GameBoard::GameBoard( QWidget *parent )
     shipCountEdit->setEchoMode( QLineEdit::Password );
 
     splashScreen = new QLabel( this );
-    splashScreen->setPixmap( iconloader->loadApplicationIcon( IMAGE_SPLASH ));
+    splashScreen->setPixmap(QPixmap(IMAGE_SPLASH));
     splashScreen->setGeometry( 0, 0, 600, 550 );
 
 
@@ -284,11 +284,13 @@ GameBoard::turn( void )
             travelTime.setNum( turnNumber + (int)dist );
 
             QString msg;
-            msg.sprintf(i18n("The distance from Planet %s to Planet %s is %s light years.\n"
-                              "A ship leaving this turn will arrive on turn %s"),
-                              sourcePlanet->getName().data(), destPlanet->getName().data(),
-                              distString.data(), travelTime.data());
-            KMsgBox::message( this, i18n("Distance"), msg, KMsgBox::INFORMATION );
+            msg = i18n("The distance from Planet %1 to Planet %2 is %3 light years.\n"
+                       "A ship leaving this turn will arrive on turn %4")
+                  .arg(sourcePlanet->getName())
+		  .arg(destPlanet->getName())
+                  .arg(distString)
+		  .arg(travelTime);
+	    QMessageBox::information( this, i18n("Distance"), msg, i18n("OK"));
 
             gameState = NONE;
             turn();
@@ -308,7 +310,7 @@ GameBoard::turn( void )
     }
 
     QString turnStr;
-    turnStr.sprintf( i18n("Turn #: %2d of %2d"), turnNumber, lastTurn );
+    turnStr = i18n("Turn #: %1 of %2").arg(turnNumber).arg(lastTurn);
 
     turnCounter->setText( turnStr );
 
@@ -423,10 +425,10 @@ GameBoard::scanForSurvivors( void )
         if( !plr->isInPlay() ) {
             // Player has bitten the dust
             QString msg;
-            msg.sprintf(i18n("The once mighty empire of %s has fallen in ruins."),
-                        plr->getName().data());
-            KMsgBox::message( this, i18n("An Empire has fallen..."),
-                              msg, KMsgBox::INFORMATION );
+            msg = i18n("The once mighty empire of %1 has fallen in ruins.")
+                  .arg(plr->getName());
+            QMessageBox::information( this, i18n("An Empire has fallen..."),
+				      msg, i18n("OK"));
         }
     }
 
@@ -435,10 +437,10 @@ GameBoard::scanForSurvivors( void )
         if( plr->isInPlay() ) {
             // Player has bitten the dust
             QString msg;
-            msg.sprintf(i18n("The fallen empire of %s has staggered back to life."),
-			plr->getName().data());
-            KMsgBox::message( this, i18n("Up from the ashes..."),
-                              msg, KMsgBox::INFORMATION );
+            msg = i18n("The fallen empire of %1 has staggered back to life.")
+		  .arg(plr->getName());
+	    QMessageBox::information( this, i18n("Up from the ashes..."),
+				      msg, i18n("OK"));
         }
     }
 }
@@ -457,10 +459,10 @@ GameBoard::doFleetArrival( AttackFleet *arrivingFleet )
         arrivingFleet->destination->getFleet().absorb(arrivingFleet);
 
         QString msg;
-        msg.sprintf(i18n("Reinforcements have arrived for planet %s"),
-                    arrivingFleet->destination->getName().data());
-        KMsgBox::message(this, i18n("Fleet Arrival"),
-                         msg, KMsgBox::INFORMATION );
+        msg = i18n("Reinforcements have arrived for planet %1")
+              .arg(arrivingFleet->destination->getName());
+        QMessageBox::information(this, i18n("Fleet Arrival"),
+				 msg, i18n("OK"));
         
     } else {
 
@@ -502,20 +504,22 @@ GameBoard::doFleetArrival( AttackFleet *arrivingFleet )
         if( planetHolds ) {
             prizePlanet.getPlayer()->statEnemyFleetsDestroyed(1);
             QString msg;
-            msg.sprintf(i18n("Planet %s has held against an attack from %s"),
-                        prizePlanet.getName().data(), attacker.owner->getName().data());
-            KMsgBox::message(this, i18n("Planet Holds"),
-                             msg, KMsgBox::INFORMATION );
+            msg = i18n("Planet %1 has held against an attack from %2")
+		  .arg(prizePlanet.getName())
+		  .arg(attacker.owner->getName());
+            QMessageBox::information(this, i18n("Planet Holds"),
+				     msg, i18n("OK"));
         } else {
             attacker.owner->statEnemyFleetsDestroyed( 1 );
 
             arrivingFleet->destination->conquer( arrivingFleet );
 
             QString msg;
-            msg.sprintf(i18n("Planet %s has fallen to %s"),
-                        prizePlanet.getName().data(), attacker.owner->getName().data());
-            KMsgBox::message(this, i18n("Planet Conquered"),
-                             msg, KMsgBox::INFORMATION );
+            msg = i18n("Planet %1 has fallen to %2")
+                  .arg(prizePlanet.getName())
+		  .arg(attacker.owner->getName());
+            QMessageBox::information(this, i18n("Planet Conquered"),
+				     msg, i18n("OK") );
 
         }
 
@@ -575,10 +579,10 @@ GameBoard::shutdownGame()
     if( !gameInProgress )
         return;
 
-    int choice = KMsgBox::yesNo( this,
-                                 i18n("End Game"),
-                                 i18n("Do you wish to retire this game?"),
-                                 0, i18n("Yes"), i18n("Cancel") );
+    int choice = QMessageBox::information( this,
+			      i18n("End Game"),
+			      i18n("Do you wish to retire this game?"),
+                              i18n("Yes"), i18n("Cancel") );
 
     if( choice != 1 )
         return;
@@ -755,7 +759,9 @@ GameBoard::sendAttackFleet( void )
                                                 shipCount, turnNumber );
 
     if( !ok ) {
-        KMsgBox::message( this, i18n("Error"), i18n("Not enough ships to send."), KMsgBox::EXCLAMATION  );
+        QMessageBox::information( this, i18n("Error"), 
+				  i18n("Not enough ships to send."), 
+				  i18n("OK"));
     }
 }
 
@@ -782,3 +788,4 @@ GameBoard::showScores()
     scoreDlg->show();
 
 }
+
