@@ -1,8 +1,10 @@
 #include <kapp.h>
+#include <klocale.h>
+#include <kglobal.h>
 #include <kmenubar.h>
 #include <ktoolbar.h>
 #include <kiconloader.h>
-#include <qpushbt.h>
+#include <qpushbutton.h>
 
 #include <iostream.h>
 
@@ -13,11 +15,12 @@
 #include "mainwin.h"
 #include "mainwin.moc"
 #include "gameboard.h"
+#include <klocale.h>
 
 // KonquestMainWindow
 
 
-MainWindow::MainWindow( const char *name) : KTopLevelWidget( name )
+MainWindow::MainWindow( const char *name) : KTMainWindow( name )
 {
 
     setCaption( i18n("GNU-Lactic Conquest") );
@@ -44,20 +47,18 @@ MainWindow::setupMenu()
     game_menu->insertItem( i18n("&Quit"), qApp, SLOT( quit() ) );
 
     QString about;
-    about.sprintf(i18n("Version %s\nCopyright (c) 1998 by\nThe Gnu-Lactic Conquest Project\n\n"
+    about = i18n("Version %1\nCopyright (c) 1998 by\nThe Gnu-Lactic Conquest Project\n\n"
         "KDE version by Russ Steffen <rsteffen@ia.net>\n"
-        "See http://www.ia.net/~rsteffen/konquest.html for more info"),
-	KONQUEST_VERSION);
+        "See http://www.ia.net/~rsteffen/konquest.html for more info")
+	.arg(KONQUEST_VERSION);
     
-    QPopupMenu *help_menu = KApplication::getKApplication()->getHelpMenu( true, about );
+    QPopupMenu *help_menu = helpMenu( about );
     
     menubar = new KMenuBar( this );
     menubar->insertItem( i18n("&Game"), game_menu );
     menubar->insertSeparator( -1 );
     menubar->insertItem( i18n("&Help"), help_menu );
 
-    menubar->enableMoving( false );
-    
     setMenu( menubar );
 }
 
@@ -66,12 +67,12 @@ MainWindow::setupToolBar()
 {
     toolbar = new KToolBar( this );
 
-    KIconLoader *iconloader = KApplication::getKApplication()->getIconLoader();
+    KIconLoader *iconloader = KGlobal::iconLoader();
 
-    QPixmap pixmap1 = iconloader->loadApplicationIcon( "stop.xpm" );
-    QPixmap pixmap2 = iconloader->loadApplicationIcon( "reload.xpm" );
-    QPixmap pixmap3 = iconloader->loadApplicationIcon( "ruler.xpm" );
-    QPixmap pixmap4 = iconloader->loadApplicationIcon( "help.xpm" );
+    QPixmap pixmap1 = iconloader->loadIcon( "stop", KIcon::Toolbar );
+    QPixmap pixmap2 = iconloader->loadIcon( "reload", KIcon::Toolbar );
+    QPixmap pixmap3 = iconloader->loadIcon( "ruler", KIcon::Toolbar );
+    QPixmap pixmap4 = iconloader->loadIcon( "help", KIcon::Toolbar );
 
     toolbar->insertButton( pixmap2, 1,
                            SIGNAL( clicked() ), gameBoard, SLOT( startNewGame() ),
@@ -134,3 +135,4 @@ MainWindow::gameStateChange( GameState newState )
 }
 
 
+
