@@ -24,6 +24,16 @@
 #define __PWIDGET__H__
 
 #include <qwidget.h>
+#include <qpopupmenu.h>
+#include <qkeycode.h>
+
+#include <kmenubar.h>
+#include <ktmainwindow.h>
+#include <ktoolbar.h>
+#include <kstatusbar.h>
+#include <kmenubar.h>
+#include <kapp.h>
+
 #include "card.h"
 #include "klondike.h"
 #include "microsol.h"
@@ -34,15 +44,6 @@
 #include "napoleon.h"
 #include "mod3.h"
 #include "freecell.h"
-#include <qpopmenu.h>
-#include <qkeycode.h>
-#include <kmenubar.h>
-#include <kmsgbox.h>
-#include <ktopwidget.h>
-#include <ktoolbar.h>
-#include <kstatusbar.h>
-#include <kmenubar.h>
-#include <kapp.h>
 
 // type identifier for games
 #define PT_NONE		0
@@ -56,10 +57,13 @@
 #define PT_MOD3		8
 #define PT_FREECELL	9
 
-class pWidget: public KTopLevelWidget {
+class pWidget: public KTMainWindow {
   Q_OBJECT
 public:
-  pWidget(QWidget *parent=0, const char *name=0 );
+  pWidget(const char *name=0 );
+
+protected:
+  virtual void focusInEvent(QFocusEvent *);
 
 private:
   void help();
@@ -73,7 +77,6 @@ private:
 private slots:
   void action(int);
   void slotToolbarChanged();
-  void slotMenubarChanged();
 
 private:
   KMenuBar *m;
@@ -81,6 +84,7 @@ private:
   KStatusBar *sb;
   dealer* dill;
   int type;
+  bool inInit;
 };
 
 #endif
