@@ -25,8 +25,10 @@
 #include <config.h>
 
 #include <stdio.h>
-#include <stdlib.h>
-#include <time.h>
+#include <kglobal.h>
+#include <kstddirs.h>
+#include <kiconloader.h>
+#include <kapp.h>
 
 #include "kpaint.moc"
 
@@ -34,69 +36,72 @@ extern CardImages  *cardImage;
 
 
 CardWidget::CardWidget( QWidget *parent, const char *name )
-: QPushButton( parent, name )
+  : QPushButton( parent, name )
 {
-	held=0;
-	move(1,1);
-	resize(cardWidth,cardHeight);
+  held=0;
+  move(1,1);
+  resize(cardWidth,cardHeight);
 }
 
 void CardWidget::paintCard(int cardType, int xPos, int yPos)
 {
-	if (cardType==0)
-	    pm=&cardImage->deck;
-	else
-	    pm=&cardImage->cardP[cardType-1];
-	if ( pm->size() != QSize( 0, 0 ) ) {         // is an image loaded?
-		bitBlt(this, xPos, yPos, pm, 0, 0, pm->size().width(), pm->size().height());
-	}
+  if (cardType==0)
+    pm=&cardImage->deck;
+  else
+    pm=&cardImage->cardP[cardType-1];
+  if ( pm->size() != QSize( 0, 0 ) ) {         // is an image loaded?
+    bitBlt(this, xPos, yPos, pm, 0, 0, pm->size().width(), pm->size().height());
+  }
 }
 
 void CardWidget::ownClick()
 {
-	emit pClicked(this);
+  emit pClicked(this);
 }
 
 void CardWidget::paintEvent( QPaintEvent *)
 {
-	bitBlt(this, 0, 0, pm, 0, 0, pm->size().width(), pm->size().height());
+  bitBlt(this, 0, 0, pm, 0, 0, pm->size().width(), pm->size().height());
 }
 
 int CardWidget::queryHeld()
 {
-	return held;
+  return held;
 }
+
 void CardWidget::setHeld(int newheld)
 {
-	held=newheld;
+  held=newheld;
 }
+
 int CardWidget::toggleHeld()
 {
-	if (held == 1)  held = 0;
-	else            held = 1;
-	return held;
+  if (held == 1)  
+    held = 0;
+  else            
+    held = 1;
+  return held;
 }
 
-bool CardImages::loadCards( const char *path)
+bool CardImages::loadCards()
 {
-	char lpath[300];
-	int w;
-	int randomDeck;
+  char lpath[300];
+  int w;
+  int randomDeck;
 	
-	for (w=0; w<highestCard; w++) {
-		sprintf(lpath,"%s%d.bmp",path,w+1);
-		if(!cardP[w].load(lpath)) 
-		    printf("Fatal error: bitmap %s not found \n",lpath);
-	}
-	
-        srandom(time(NULL));
+  QString fname;
+  for (w=0; w<highestCard; w++) {
+    fname=KGlobal::dirs()->findResource("appdata", QString("pics/%1.png").arg(w+1));
 
-        randomDeck=(random() % 4) +1;
-//        randomDeck+=1;
+    if(!cardP[w].load(fname))
+      printf("Fatal error: bitmap %s not found \n",lpath);
+  }
 	
-	sprintf(lpath,"%sdeck%d.bmp",path, randomDeck);
-	if(!deck.load(lpath)) 
-	    printf("Fatal error: bitmap %s not found \n",lpath);
-	return 1;
+  randomDeck=(kapp->random() % 4) +1;
+	
+  fname = KGlobal::dirs()->findResource("appdata", 
+					QString("pics/deck%1.png").arg(randomDeck));
+  if(!deck.load(fname))
+    printf("Fatal error: bitmap %s not found \n",fname.ascii());
+  return 1;
 }
-
