@@ -1,6 +1,8 @@
+#ifndef __CardWidget__
+#define __CardWidget__
+
 #include <qpixmap.h>
-#include <qwindow.h>
-#include <qpushbt.h>
+#include <qpushbutton.h>
 #include <qlabel.h>
 
 #include "defines.h"
@@ -33,15 +35,17 @@ private:
 	int         held;
 };
 
-class CardImages : public QWindow
+class CardImages : public QWidget
 {
 	Q_OBJECT
 public:
-	CardImages( QWidget *parent=0, const char *name=0 ) : QWindow( parent, name ) {
+	CardImages( QWidget *parent=0, const char *name=0 ) : QWidget( parent, name ) {
 	}
 	
-	bool        loadCards( const char *path);
+	bool        loadCards();
 	
 	QPixmap     cardP[52];
 	QPixmap     deck;
 };
+
+#endif
