@@ -21,18 +21,17 @@
  * bad parts just send me a patch including you "elegant" code ;)
 */  
 
-#include<qpopmenu.h>
+#include<qpopupmenu.h>
 #include<qlayout.h>
 #include<qpixmap.h>
 #include<qkeycode.h>
 
 #include<kiconloader.h>
 #include<kapp.h>
-#include<ktopwidget.h>
+#include<ktmainwindow.h>
 #include<kmenubar.h>
 #include<ktoolbar.h>
 #include<kstatusbar.h>
-#include<kmsgbox.h>
 
 #include "kpoker.h"
 
@@ -42,12 +41,10 @@
 const int ID_SOUND = 100;
 int soId;
 
-PokerWindow::PokerWindow() :   KTopLevelWidget()
+PokerWindow::PokerWindow() :   KTMainWindow()
 {
         int i;
 
-	locale = kapp->getLocale();
-	
 	_kpok = new kpok(this,0);
 	setView( _kpok, FALSE );
 	_kpok->show();
@@ -58,16 +55,16 @@ PokerWindow::PokerWindow() :   KTopLevelWidget()
 	
 	
 	filePopup = new QPopupMenu(0,"fpopup");
-	filePopup->insertItem(locale->translate("&New game"),_kpok,SLOT(initPoker()));
+	filePopup->insertItem(i18n("&New game"),_kpok,SLOT(initPoker()));
 	filePopup->insertSeparator();
-	filePopup->insertItem(locale->translate("&Quit"), qApp, SLOT(quit()));
+	filePopup->insertItem(i18n("&Quit"), qApp, SLOT(quit()));
 
        	optionsPopup = new QPopupMenu(0,"oppup");
 	
-	soId = optionsPopup->insertItem(locale->translate("&Sound"), this, SLOT(toggleSound()));
+	soId = optionsPopup->insertItem(i18n("&Sound"), this, SLOT(toggleSound()));
 	optionsPopup->setCheckable(TRUE);
 
-	QPopupMenu *help = kapp->getHelpMenu(true, QString(i18n("Poker"))
+	QPopupMenu *help = helpMenu( i18n("Poker")
 					 + " " + KPOKER_VERSION + " released " + KPOKER_RELEASE_DATE
                                          + i18n("\n\nby Jochen Tuchbreiter")
                                          + " (whynot@mabi.de)"
@@ -75,11 +72,11 @@ PokerWindow::PokerWindow() :   KTopLevelWidget()
 					 + i18n("\nSuggestions, bug reports etc. are welcome")
 					     );
 
-	menu->insertItem(locale->translate("&File"), filePopup);
-	menu->insertItem(locale->translate("&Options"), optionsPopup);
+	menu->insertItem(i18n("&File"), filePopup);
+	menu->insertItem(i18n("&Options"), optionsPopup);
 	
 	menu->insertSeparator();
-	menu->insertItem(locale->translate("&Help"), help);
+	menu->insertItem(i18n("&Help"), help);
 
 	setMenu( menu );
 
@@ -89,7 +86,7 @@ PokerWindow::PokerWindow() :   KTopLevelWidget()
 	else {
 	  optionsPopup->setItemEnabled(soId, FALSE);
 	}
-	conf = kapp->getConfig();
+	conf = kapp->config();
 
 	if (conf !=0) {
 	  if ((i = conf->readNumEntry("Sound", -1)) != -1) {
