@@ -41,32 +41,38 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <qaccel.h>
-#include <qpopmenu.h>
-#include <kmsgbox.h>
+#include <qpopupmenu.h>
 #include <kapp.h>
-#include <kmsgbox.h>
-#include <qpushbt.h>
+#include <qpushbutton.h>
 #include <qlistbox.h>
-#include <qdatetm.h>
+#include <qdatetime.h>
 #include <qlabel.h>
-#include <qlined.h>
+#include <qlineedit.h>
 #include <kconfig.h>
 #include <kcolordlg.h>
 #include <qregexp.h>
 #include <qtimer.h>
 #include <qlayout.h>
-#include "Score.h"
-#include "app.h"
-#include "about.h"
-#include "playsound.h"
 #include <kseparator.h>
 #include <kwm.h>
-#include <qmsgbox.h>
+#include <qmessagebox.h>
+#include <kstddirs.h>
+#include <kglobal.h>
+#include <kiconloader.h>
+#include <khelpmenu.h>
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include "Score.h"
+#include "app.h"
+#include "about.h"
+#include "playsound.h"
+
+#define APPDATA(x) KGlobal::dirs()->findResource("appdata", x)
+#define PICDATA(x) KGlobal::dirs()->findResource("appdata", QString("pics/")+ x)
+
 const int ID_FSAVE	= 101;
 const int ID_FLOAD	= 102;
 const int ID_FQUIT	= 104;
@@ -107,25 +113,21 @@ const int ID_OSOUND	= 580;
 const int ID_OGSCALE	= 581;
 
 const int ID_HCONTENTS	= 900;
-const int ID_HABOUT	= 2;
+const int ID_HABOUT	= 902;
 const int ID_HHINT	= 903;
 const int ID_HRULES	= 904;
 const int ID_HSTRATEGY	= 905;
 const int ID_HABOUTQT	= 906;
+const int ID_HABOUTKDE	= 907;
 
 const int SB_SCOREH	= 2;
 const int SB_SCOREC	= 3;
 const int SB_TURN       = 4;
 
-extern QString PICDIR;
-
-App::App() : KTopLevelWidget() {
-  // create locale
-  locale = kapp->getLocale();
-
+App::App() : KTMainWindow() {
   highscore.resize(0);
   readHighscore();
-  setCaption( kapp->getCaption() );
+  setCaption( kapp->caption() );
 
   // create reversi board
   b = new Board(this);
@@ -152,17 +154,9 @@ App::App() : KTopLevelWidget() {
 
   b->start();
 
-#define menuPosition
-  connect(menu, SIGNAL(moved(menuPosition)),
-	  this, SLOT(slotBarChanged()));
-#undef menuPosition
+  connect(tb, SIGNAL(moved(BarPosition)), this, SLOT(slotBarChanged()));
 
-#define BarPosition
-  connect(tb, SIGNAL(moved(BarPosition)),
-	  this, SLOT(slotBarChanged()));
-#undef BarPosition
-
-  KConfig *conf = kapp->getConfig();
+  KConfig *conf = kapp->config();
   if(conf != 0) {
     if(conf->readNumEntry("Background", -1) != -1) {
       int i = conf->readNumEntry("Background");
@@ -190,11 +184,6 @@ App::App() : KTopLevelWidget() {
       updateRects();
     }
 
-    // set menubar position
-    int mbpos = conf->readNumEntry("Menubar_Pos",
-				   (int)(KMenuBar::Top));
-    menu->setMenuBarPos((KMenuBar::menuPosition)mbpos);
-
     // set toolbar position
     int tbpos = conf->readNumEntry("Toolbar_1_Pos",
 				   (int)(KToolBar::Top));
@@ -214,10 +203,10 @@ App::App() : KTopLevelWidget() {
       if(!audioOK()) {
 	show();
 	kapp->processEvents();
-	KMsgBox::message(this, locale->translate("Error"),
-			 locale->translate("A problem with the sound server "
-			 "occured!\nCannot enable sound "
-			 "support."), KMsgBox::STOP);	
+	QMessageBox::warning(this, i18n("Error"),
+			     i18n("A problem with the sound server "
+				  "occured!\nCannot enable sound "
+				  "support."), i18n("OK"));
       }
     } else
       doneAudio(); // just to be sure
@@ -242,96 +231,111 @@ void App::createMenuBar() {
   menu = new KMenuBar(this);
 
   QPopupMenu *fm = new QPopupMenu;
-  fm->insertItem(locale->translate("&New game"), ID_GNEW);
-  fm->insertItem(locale->translate("&Load game"), ID_FLOAD);
-  fm->insertItem(locale->translate("&Save game"), ID_FSAVE);
+  fm->insertItem(i18n("&New game"), ID_GNEW);
+  fm->insertItem(i18n("&Load game"), ID_FLOAD);
+  fm->insertItem(i18n("&Save game"), ID_FSAVE);
   fm->insertSeparator();
-  fm->insertItem(locale->translate("&Quit"), ID_FQUIT);
+  fm->insertItem(i18n("&Quit"), ID_FQUIT);
 
   QPopupMenu *gm = new QPopupMenu;
-  gm->insertItem(locale->translate("Get &hint"), ID_HHINT);
+  gm->insertItem(i18n("Get &hint"), ID_HHINT);
   gm->insertSeparator();  
-  gm->insertItem(locale->translate("&Stop thinking"), ID_GSTOP);
-  gm->insertItem(locale->translate("&Continue"), ID_GCONTINUE);
+  gm->insertItem(i18n("&Stop thinking"), ID_GSTOP);
+  gm->insertItem(i18n("&Continue"), ID_GCONTINUE);
   gm->insertSeparator();
-  gm->insertItem(locale->translate("&Undo move"), ID_GUNDO);
-  gm->insertItem(locale->translate("Switch si&des"), ID_GSWITCH);
+  gm->insertItem(i18n("&Undo move"), ID_GUNDO);
+  gm->insertItem(i18n("Switch si&des"), ID_GSWITCH);
   gm->insertSeparator();
-  gm->insertItem(locale->translate("Hall Of &Fame..."), ID_GHIGHSCORES);
+  gm->insertItem(i18n("Hall Of &Fame..."), ID_GHIGHSCORES);
   
   QPopupMenu *om = new QPopupMenu;
   om->setCheckable(TRUE);
   QPopupMenu *om_s = new QPopupMenu;  
   om_s->setCheckable(TRUE);
-  om_s->insertItem(locale->translate("Level 1 (Wimp)"), ID_O2);
-  om_s->insertItem(locale->translate("Level 2 (Beginner)"), ID_O3);
-  om_s->insertItem(locale->translate("Level 3 (Novice)"),  ID_O4);
-  om_s->insertItem(locale->translate("Level 4 (Average)"),  ID_O5);
-  om_s->insertItem(locale->translate("Level 5 (Good)"),  ID_O6);
-  om_s->insertItem(locale->translate("Level 6 (Expert)"),  ID_O7);
-  om_s->insertItem(locale->translate("Level 7 (Master)"),  ID_O8);
-  om->insertItem(locale->translate("Skill"), om_s);
+  om_s->insertItem(i18n("Level 1 (Wimp)"), ID_O2);
+  om_s->insertItem(i18n("Level 2 (Beginner)"), ID_O3);
+  om_s->insertItem(i18n("Level 3 (Novice)"),  ID_O4);
+  om_s->insertItem(i18n("Level 4 (Average)"),  ID_O5);
+  om_s->insertItem(i18n("Level 5 (Good)"),  ID_O6);
+  om_s->insertItem(i18n("Level 6 (Expert)"),  ID_O7);
+  om_s->insertItem(i18n("Level 7 (Master)"),  ID_O8);
+  om->insertItem(i18n("Skill"), om_s);
   om->insertSeparator();
-  om->insertItem(locale->translate("&Shrink board"), ID_VZOOMOUT);
-  om->insertItem(locale->translate("&Enlarge board"), ID_VZOOMIN);
+  om->insertItem(i18n("&Shrink board"), ID_VZOOMOUT);
+  om->insertItem(i18n("&Enlarge board"), ID_VZOOMIN);
 
   QPopupMenu *zm = new QPopupMenu;
   zm->setCheckable(TRUE);
-  zm->insertItem(locale->translate("&Half size"), ID_VZOOM50);
-  zm->insertItem(locale->translate("60%"), ID_VZOOM60);
-  zm->insertItem(locale->translate("80%"), ID_VZOOM80);
-  zm->insertItem(locale->translate("D&efault size"), ID_VZOOM100);
-  zm->insertItem(locale->translate("120%"), ID_VZOOM120);
-  zm->insertItem(locale->translate("140%"), ID_VZOOM140);
-  zm->insertItem(locale->translate("160%"), ID_VZOOM160);
-  zm->insertItem(locale->translate("180%"), ID_VZOOM180);
-  zm->insertItem(locale->translate("&Double size"), ID_VZOOM200);
-  om->insertItem(locale->translate("Set size"), zm);
+  zm->insertItem(i18n("&Half size"), ID_VZOOM50);
+  zm->insertItem(i18n("60%"), ID_VZOOM60);
+  zm->insertItem(i18n("80%"), ID_VZOOM80);
+  zm->insertItem(i18n("D&efault size"), ID_VZOOM100);
+  zm->insertItem(i18n("120%"), ID_VZOOM120);
+  zm->insertItem(i18n("140%"), ID_VZOOM140);
+  zm->insertItem(i18n("160%"), ID_VZOOM160);
+  zm->insertItem(i18n("180%"), ID_VZOOM180);
+  zm->insertItem(i18n("&Double size"), ID_VZOOM200);
+  om->insertItem(i18n("Set size"), zm);
 
   om->insertSeparator();
-  om->insertItem(locale->translate("Select &background color..."), ID_COLOR);
+  om->insertItem(i18n("Select &background color..."), ID_COLOR);
   
   QPopupMenu *om_bg = new QPopupMenu;
   lookupBackgroundPixmaps();
 
   if(backgroundPixmaps.count() == 0)
-    om_bg->insertItem(locale->translate("none"), ID_PIXMAP);
-  else
+    om_bg->insertItem(i18n("none"), ID_PIXMAP);
+  else {
+    QPopupMenu *current = om_bg;
     for(unsigned i = 0; i < backgroundPixmaps.count(); i++) {
       // since the filename may contain underscore, they
       // are replaced with spaces in the menu entry
       QString s(backgroundPixmaps.at(i)->baseName());
       s = s.replace(QRegExp("_"), " ");
-      om_bg->insertItem((const char *)s, ID_PIXMAP + i);
+      
+      // avoid too longish menus
+      if(current->count() > 20) {
+	QPopupMenu *newmenu = new QPopupMenu;
+	current->insertItem(i18n("More..."), newmenu);
+	current = newmenu;
+      }
+
+      current->insertItem((const char *)s, ID_PIXMAP + i);
     }
+  }
   
-  om->insertItem(locale->translate("Select background image"), om_bg);
-  om->insertItem(locale->translate("&Grayscale"), ID_OGSCALE);
+  om->insertItem(i18n("Select background image"), om_bg);
+  om->insertItem(i18n("&Grayscale"), ID_OGSCALE);
   om->insertSeparator();
-  om->insertItem(locale->translate("&Animations"), ID_OANIMATION);
+  om->insertItem(i18n("&Animations"), ID_OANIMATION);
 
   QPopupMenu *om_sp = new QPopupMenu;
   om_sp->setCheckable(TRUE);
-  om_sp->insertItem(locale->translate("1 (fastest)"), ID_OSPEED+1);
+  om_sp->insertItem(i18n("1 (fastest)"), ID_OSPEED+1);
   for(int i = ID_OSPEED+2; i < ID_OSPEED + 10; i++) {
     QString txt;
     txt.setNum(i - ID_OSPEED);
     om_sp->insertItem((const char *)txt, i);
   }
-  om_sp->insertItem(locale->translate("10 (slowest)"), ID_OSPEED+10);
-  om->insertItem(locale->translate("Animation speed"), om_sp, ID_OSPEED);
+  om_sp->insertItem(i18n("10 (slowest)"), ID_OSPEED+10);
+  om->insertItem(i18n("Animation speed"), om_sp, ID_OSPEED);
 #ifdef HAVE_MEDIATOOL
   om->insertSeparator();
-  om->insertItem(locale->translate("S&ound"), ID_OSOUND);
+  om->insertItem(i18n("S&ound"), ID_OSOUND);
 #endif
 
-  QPopupMenu *help = kapp->getHelpMenu(true, 0);  // Use our own About box
+  QPopupMenu *help = helpMenu(QString::null);  // Use our own About box
+  help = new QPopupMenu;
+  help->insertItem(i18n("&Contents"), ID_HCONTENTS);
+  help->insertSeparator();
+  help->insertItem(i18n("&About")+" "+kapp->name() + "...", ID_HABOUT);
+  help->insertItem(i18n("About &KDE..."), ID_HABOUTKDE);
 
-  menu->insertItem(locale->translate("&File"), fm);
-  menu->insertItem(locale->translate("&Game"), gm);
-  menu->insertItem(locale->translate("&Options"), om);
+  menu->insertItem(i18n("&File"), fm);
+  menu->insertItem(i18n("&Game"), gm);
+  menu->insertItem(i18n("&Options"), om);
   menu->insertSeparator();
-  menu->insertItem(locale->translate("&Help"), help);
+  menu->insertItem(i18n("&Help"), help);
   connect(menu, SIGNAL(activated(int)), this, SLOT(processEvent(int)));
 
   menu->setAccel(CTRL+Key_S, ID_FSAVE);
@@ -357,35 +361,43 @@ void App::createMenuBar() {
   menu->setItemEnabled(ID_PIXMAP, backgroundPixmaps.count()!=0);
 }
 
+#ifdef ICON
+#undef ICON
+#endif
+
+#define ICON(x) QPixmap(PICDATA(x))
 
 void App::createToolBar() {
   tb = new KToolBar(this);
-  QPixmap p1((const char *)(PICDIR + "stop.xpm"));
-  QPixmap p2((const char *)(PICDIR + "zoomin.xpm"));
-  QPixmap p3((const char *)(PICDIR + "zoomout.xpm"));
-  QPixmap p4((const char *)(PICDIR + "undo.xpm"));
-  QPixmap p5((const char *)(PICDIR + "hint.xpm"));
-  QPixmap p6((const char *)(PICDIR + "help.xpm"));
-  tb->insertButton(p1, ID_GSTOP, TRUE, locale->translate("Stop thinking"));
-  tb->insertButton(p4, ID_GUNDO, TRUE, locale->translate("Undo move"));
-  tb->insertButton(p3, ID_VZOOMOUT, TRUE, locale->translate("Shrink board"));
-  tb->insertButton(p2, ID_VZOOMIN, TRUE, locale->translate("Enlarge board"));  
-  tb->insertButton(p5, ID_HHINT, TRUE, locale->translate("Get hint"));
-  tb->insertButton(p6, ID_HCONTENTS, TRUE, locale->translate("Get help"));
+
+  tb->insertButton(ICON("stop.xpm"), 
+		   ID_GSTOP, TRUE, i18n("Stop thinking"));
+  tb->insertButton(ICON("undo.xpm"), 
+		   ID_GUNDO, TRUE, i18n("Undo move"));
+  tb->insertButton(ICON("zoomout.xpm"), 
+		   ID_VZOOMOUT, TRUE, i18n("Shrink board"));
+  tb->insertButton(ICON("zoomin.xpm"),
+		   ID_VZOOMIN, TRUE, i18n("Enlarge board"));  
+  tb->insertButton(ICON("hint.xpm"), 
+		   ID_HHINT, TRUE, i18n("Get hint"));
+  tb->insertButton(ICON("help.xpm"), 
+		   ID_HCONTENTS, TRUE, i18n("Get help"));
   connect(tb, SIGNAL(clicked(int)), this, SLOT(processEvent(int)));  
 }
 
 
 void App::createStatusBar() {
   sb = new KStatusBar(this);
-  sb->insertItem(locale->translate("XXXXX's turn"), SB_TURN);
-  sb->insertItem(locale->translate("You (XXXXX): 88"), SB_SCOREH);
-  sb->insertItem(locale->translate("Computer (XXXXX): 88"), SB_SCOREC);
+  sb->insertItem(i18n("XXXXX's turn"), SB_TURN);
+  sb->insertItem(i18n("You (XXXXX): 88"), SB_SCOREH);
+  sb->insertItem(i18n("Computer (XXXXX): 88"), SB_SCOREC);
 }
 
 
-void App::lookupBackgroundPixmaps() {  
-  QDir dir((const char *)(PICDIR + "background/"), "*.xpm");
+void App::lookupBackgroundPixmaps() {
+  QString PICDIR = KGlobal::dirs()->findResourceDir("wallpaper", "chess.jpg");
+
+  QDir dir(PICDIR, "*.jpg");
   if(!dir.exists())
     return;
 
@@ -417,22 +429,22 @@ void App::processEvent(int itemid) {
 
   case ID_HCONTENTS:
   {
-      KApplication::getKApplication()->invokeHTMLHelp("", "");  
+      KApplication::kApplication()->invokeHTMLHelp("", "");  
       break;
   }
   case ID_FSAVE:
     {
-      KConfig *config = kapp->getConfig();
+      KConfig *config = kapp->config();
       config->setGroup("Savegame");
       b->saveGame(config);
-      KMsgBox::message(this, "Information", 
-		       locale->translate("Game saved"));
+      QMessageBox::information(this, kapp->caption(),
+                               i18n("Game saved"), i18n("OK"));
     }
     break;
 
   case ID_FLOAD: 
     {
-      KConfig *config = kapp->getConfig();
+      KConfig *config = kapp->config();
       config->setGroup("Savegame");
 
       if(b->canLoad(config))
@@ -477,14 +489,14 @@ void App::processEvent(int itemid) {
     b->zoomIn();
     b->setFixedSize(b->sizeHint());
     updateRects();
-    kapp->getConfig()->writeEntry("Zoom", b->getZoom());
+    kapp->config()->writeEntry("Zoom", b->getZoom());
     break;
     
   case ID_VZOOMOUT:
     b->zoomOut();
     b->setFixedSize(b->sizeHint());
     updateRects();
-    kapp->getConfig()->writeEntry("Zoom", b->getZoom());
+    kapp->config()->writeEntry("Zoom", b->getZoom());
     break;
 
   case ID_VZOOM50:
@@ -499,12 +511,12 @@ void App::processEvent(int itemid) {
     b->setZoom(itemid - ID_VZOOMBASE);
     b->setFixedSize(b->sizeHint());
     updateRects();
-    kapp->getConfig()->writeEntry("Zoom", b->getZoom());
+    kapp->config()->writeEntry("Zoom", b->getZoom());
     break;
 
   case ID_OANIMATION:
     b->setAnimationSpeed(-b->animationSpeed());
-    kapp->getConfig()->writeEntry("AnimationSpeed", b->animationSpeed());
+    kapp->config()->writeEntry("AnimationSpeed", b->animationSpeed());
     break;
 
   case ID_OGSCALE:
@@ -519,7 +531,7 @@ void App::processEvent(int itemid) {
 	gs = FALSE;
       }
       menu->setItemChecked(ID_OGSCALE, gs);
-      kapp->getConfig()->writeEntry("Grayscale", gs);
+      kapp->config()->writeEntry("Grayscale", gs);
     }
 
   case ID_O2:
@@ -530,16 +542,16 @@ void App::processEvent(int itemid) {
   case ID_O7:
   case ID_O8:
     b->setStrength(itemid - ID_OBASE);
-    kapp->getConfig()->writeEntry("Skill", itemid - ID_OBASE);
+    kapp->config()->writeEntry("Skill", itemid - ID_OBASE);
     break;
 
   case ID_COLOR:
     {
       if(KColorDialog::getColor(c)) {
 	b->setColor(c);
-	kapp->getConfig()->writeEntry("Background", 1);
-	s.sprintf("%d %d %d", c.red(), c.green(), c.blue());
-	kapp->getConfig()->writeEntry("BackgroundColor", (const char *)s);
+	kapp->config()->writeEntry("Background", 1);
+	s = QString("%1 %2 %3").arg(c.red()).arg(c.green()).arg(c.blue());
+	kapp->config()->writeEntry("BackgroundColor", s);
       }
     };
     break;
@@ -549,16 +561,16 @@ void App::processEvent(int itemid) {
     if(!audioOK()) {
       initAudio();
       if(!audioOK()) {
-	KMsgBox::message(this, locale->translate("Error"), 
-			 locale->translate("A problem with the sound server "
-			 "occured!\nCannot enable sound "
-			 "support."), KMsgBox::STOP);
-	kapp->getConfig()->writeEntry("Sound", 0);
+	QMessageBox::warning(this, i18n("Error"), 
+			     i18n("A problem with the sound server "
+				  "occured!\nCannot enable sound "
+				  "support."), i18n("OK"));
+	kapp->config()->writeEntry("Sound", 0);
       } else 
-	kapp->getConfig()->writeEntry("Sound", 1);  
+	kapp->config()->writeEntry("Sound", 1);  
     } else {
       doneAudio();
-      kapp->getConfig()->writeEntry("Sound", 0);
+      kapp->config()->writeEntry("Sound", 0);
     }
     break;
 #endif
@@ -575,20 +587,28 @@ void App::processEvent(int itemid) {
     }
   break;
 
+  case ID_HABOUTKDE:
+    {
+	KHelpMenu hm;
+	hm.aboutKDE();
+    }
+    break;
+
   default:
     {
       if((itemid >= ID_PIXMAP) && (itemid < ID_PIXMAP + (int)backgroundPixmaps.count())) {
 	QPixmap pm(backgroundPixmaps.at(itemid - ID_PIXMAP)->filePath());
 	b->setPixmap(pm);
-	kapp->getConfig()->writeEntry("Background", 2);
-	s.sprintf("%d %d %d", c.red(), c.green(), c.blue());
-	kapp->getConfig()->writeEntry("BackgroundPixmap",
+	kapp->config()->writeEntry("Background", 2);
+	s = QString("%1 %2 %3").arg(c.red()).arg(c.green()).arg(c.blue());
+	kapp->config()->writeEntry("BackgroundPixmap",
 				      backgroundPixmaps.at(itemid - ID_PIXMAP)->filePath());
       } else if((itemid >= ID_OSPEED) && (itemid <= ID_OSPEED + 10)) {
 	b->setAnimationSpeed(itemid - ID_OSPEED);
-	kapp->getConfig()->writeEntry("AnimationSpeed", b->animationSpeed());
+	kapp->config()->writeEntry("AnimationSpeed", b->animationSpeed());
       } else
-	KMsgBox::message(this, locale->translate("Information"), locale->translate("not yet implemented"));
+	QMessageBox::information(this, i18n("Information"), 
+				 i18n("not yet implemented"), i18n("Then do it!"));
     }
   }
   enableItems();
@@ -601,19 +621,15 @@ void App::slotScore() {
 
   b->getScore(black, white);
   if(b->humanIs() == Score::BLACK) {
-    s1.sprintf(locale->translate("You (%s): %d"), 
-	       locale->translate("blue"), black);
-    s2.sprintf(locale->translate("Computer (%s): %d"), 
-	       locale->translate("red"), white);
+    s1 = i18n("You (blue): %1").arg(black);
+    s2 = i18n("Computer (red): %1").arg(white);
   } else {
-    s2.sprintf(locale->translate("You (%s): %d"), 
-	       locale->translate("red"), white);
-    s1.sprintf(locale->translate("Computer (%s): %d"), 
-	       locale->translate("blue"), black);
+    s2 = i18n("You (red): %1").arg(white);
+    s1 = i18n("Computer (blue): %1").arg(black);
   }
 
-  sb->changeItem((char *)(const char *)s1, SB_SCOREH);
-  sb->changeItem((char *)(const char *)s2, SB_SCOREC);
+  sb->changeItem(s1, SB_SCOREH);
+  sb->changeItem(s2, SB_SCOREC);
   enableItems();
 }
 
@@ -653,7 +669,7 @@ void App::slotGameEnded(int color) {
   QString s;
   int winner, loser;
 
-  sb->changeItem(locale->translate("End of game"), SB_TURN);
+  sb->changeItem(i18n("End of game"), SB_TURN);
     
   // get the score
   if(color == Score::BLACK) 
@@ -662,9 +678,9 @@ void App::slotGameEnded(int color) {
     b->getScore(loser, winner);
   
   if(color == Score::NOBODY) {
-    playSound("drawn.wav");
-    s.sprintf(locale->translate("Game is drawn!\n\nYou     : %d\nComputer: %d"), winner, loser);
-    KMsgBox::message(this, locale->translate("Game ended"), (const char *)s);
+    playSound("reversi-drawn.wav");
+    s = i18n("Game is drawn!\n\nYou     : %1\nComputer: %2").arg(winner).arg(loser);
+    QMessageBox::information(this, i18n("Game ended"), s, i18n("OK"));
   } else if(b->humanIs() == color) {
     // calculate score
     int  st = b->getStrength();
@@ -673,10 +689,10 @@ void App::slotGameEnded(int color) {
                  (st - (ID_O2 - ID_OBASE) + 1) / (ID_O8 - ID_O2 + 1) * 
                  100.0;
 
-    playSound("won.wav");
-    s.sprintf(locale->translate("Congratulations, you have won!\n\nYou     : %d\nComputer: %d\nYour rating %4.1f%%"), 
-	      winner, loser, score);
-    KMsgBox::message(this, locale->translate("Game ended"), (const char *)s);
+    playSound("reversi-won.wav");
+    s = i18n("Congratulations, you have won!\n\nYou     : %1\nComputer: %2\nYour rating %3%%")
+	      .arg(winner).arg(loser).arg(score,1);
+    QMessageBox::information(this, i18n("Game ended"), s, i18n("OK"));
 
     // create highscore entry
     HighScore hs;
@@ -693,10 +709,10 @@ void App::slotGameEnded(int color) {
       showHighscore(rank);
     }
   } else {
-    playSound("lost.wav");
-    s.sprintf(locale->translate("You have lost the game!\n\nYou     : %d\nComputer: %d"), 
-	      loser, winner);
-    KMsgBox::message(this, locale->translate("Game ended"), (const char *)s);
+    playSound("reversi-lost.wav");
+    s = i18n("You have lost the game!\n\nYou     : %1\nComputer: %2")
+	      .arg(loser).arg(winner);
+    QMessageBox::information(this, i18n("Game ended"), s, i18n("OK"));
   }
 }
 
@@ -705,12 +721,12 @@ void App::slotTurn(int color) {
   QString s;
 
   if(color == Score::WHITE)
-    s.sprintf("%s %s", locale->translate("Red's"), locale->translate("turn"));
+    s = i18n("Red's turn");
   else if(color == Score::BLACK)
-    s.sprintf("%s %s", locale->translate("Blue's"), locale->translate("turn"));
+    s = i18n("Blue's turn");
   else
     s = "";
-  sb->changeItem(s.data(), SB_TURN);
+  sb->changeItem(s, SB_TURN);
 }
 
 
@@ -738,7 +754,7 @@ void App::slotIllegalMove() {
   if(!audioOK())
     kapp->beep();
   else
-    playSound("illegalmove.wav");
+    playSound("reversi-illegalmove.wav");
 }
 
 
@@ -795,7 +811,7 @@ int App::insertHighscore(HighScore &hs) {
 void App::readHighscore() {
   int i;
   QString s, e, grp;
-  KConfig *conf = kapp->getConfig();
+  KConfig *conf = kapp->config();
 
   highscore.resize(0);
   i = 0;
@@ -803,9 +819,9 @@ void App::readHighscore() {
   grp = conf->group();
   conf->setGroup("Hall of Fame");
   while ((i < HIGHSCORE_MAX) && !eol) {
-    s.sprintf("Highscore_%d", i);
+    s = QString("Highscore_%1").arg(i);
     if(conf->hasKey(s)) {
-      e = conf->readEntry(s.data());
+      e = conf->readEntry(s);
       highscore.resize(i+1);
 
       HighScore hs;
@@ -819,28 +835,28 @@ void App::readHighscore() {
   }
 
   // restore old group
-  conf->setGroup(grp.data());
+  conf->setGroup(grp);
 }
 
 
 void App::writeHighscore() {
   int i;
   QString s, e, grp;
-  KConfig *conf = kapp->getConfig();
+  KConfig *conf = kapp->config();
 
   grp = conf->group();
   conf->setGroup("Hall of Fame");
   for(i = 0; i < (int)highscore.size(); i++) {
-    s.sprintf("Highscore_%d", i);
+    s = QString("Highscore_%1").arg(i);
     HighScore hs = highscore[i];
-    e.sprintf("%s %d %d %d %f %ld", 
-	      hs.name, hs.color, hs.winner,
-	      hs.loser, hs.rating, hs.date);
+    e = QString("%1 %2 %3 %4 %5 %6")
+	      .arg(hs.name).arg(hs.color).arg(hs.winner)
+	      .arg(hs.loser).arg(hs.rating).arg(hs.date);
     conf->writeEntry(s, e);
   }
   
   // restore old group
-  conf->setGroup(grp.data());
+  conf->setGroup(grp);
 }
 
 int MAX(int a, int b) {
@@ -852,12 +868,12 @@ int MAX(int a, int b) {
 
 void App::showHighscore(int focusitem) {
   // this may look a little bit confusing...
-  QDialog *dlg = new QDialog(0, locale->translate("Hall of Fame"), TRUE);
-  dlg->setCaption(locale->translate("KReversi: Hall Of Fame"));
+  QDialog *dlg = new QDialog(0, i18n("Hall of Fame"), TRUE);
+  dlg->setCaption(i18n("KReversi: Hall Of Fame"));
 
   QVBoxLayout *tl = new QVBoxLayout(dlg, 10);
   
-  QLabel *l = new QLabel(locale->translate("KReversi: Hall Of Fame"), dlg);
+  QLabel *l = new QLabel(i18n("KReversi: Hall Of Fame"), dlg);
   QFont f = font();
   f.setPointSize(24);
   f.setBold(TRUE);
@@ -878,23 +894,23 @@ void App::showHighscore(int focusitem) {
   // add titles
   f = font();
   f.setBold(TRUE);
-  l = new QLabel(locale->translate("Rank"), dlg);
+  l = new QLabel(i18n("Rank"), dlg);
   l->setFont(f);
   l->setMinimumSize(l->sizeHint());
   table->addWidget(l, 0, 0);
-  l = new QLabel(locale->translate("Name"), dlg);
+  l = new QLabel(i18n("Name"), dlg);
   l->setFont(f);
   l->setMinimumSize(l->sizeHint());
   table->addWidget(l, 0, 1);
-  l = new QLabel(locale->translate("Color"), dlg);
+  l = new QLabel(i18n("Color"), dlg);
   l->setFont(f);
   l->setMinimumSize(l->sizeHint());
   table->addWidget(l, 0, 2);
-  l = new QLabel(locale->translate("Score"), dlg);
+  l = new QLabel(i18n("Score"), dlg);
   l->setFont(f);
   l->setMinimumSize(l->sizeHint());
   table->addWidget(l, 0, 3);
-  l = new QLabel(locale->translate("Rating"), dlg);
+  l = new QLabel(i18n("Rating"), dlg);
   l->setFont(f);
   l->setMinimumSize(l->sizeHint());
   table->addWidget(l, 0, 4);
@@ -909,14 +925,14 @@ void App::showHighscore(int focusitem) {
     if(i < highscore.size()) {
       hs = highscore[i];
       if(hs.color == Score::BLACK)
-	color = locale->translate("blue");
+	color = i18n("blue");
       else
-	color = locale->translate("red");
+	color = i18n("red");
     }
     
     // insert rank    
-    s.sprintf("%d", i+1);
-    e[i][0] = new QLabel(s.data(), dlg);
+    s.setNum(i+1);
+    e[i][0] = new QLabel(s, dlg);
 
     // insert name
     if(i < highscore.size())
@@ -932,17 +948,17 @@ void App::showHighscore(int focusitem) {
 
     // insert score
     if(i < highscore.size())
-      s.sprintf("%d/%d", hs.winner, hs.loser);
+      s = QString("%1/%2").arg(hs.winner).arg(hs.loser);
     else
       s = "";
-    e[i][3] = new QLabel(s.data(), dlg);
+    e[i][3] = new QLabel(s, dlg);
     
     // insert rating
     if(i < highscore.size())
       s.sprintf("%3.0f", hs.rating);
     else
       s = "";
-    e[i][4] = new QLabel(s.data(), dlg);
+    e[i][4] = new QLabel(s, dlg);
   }
 
   f = font();
@@ -956,7 +972,7 @@ void App::showHighscore(int focusitem) {
       table->addWidget(e[i][j], i+2, j, AlignCenter);	
     }
     
-  QPushButton *b = new QPushButton(locale->translate("Close"), dlg);
+  QPushButton *b = new QPushButton(i18n("Close"), dlg);
   if(style() == MotifStyle)
     b->setFixedSize(b->sizeHint().width() + 10,
 		    b->sizeHint().height() + 10);
@@ -975,7 +991,7 @@ void App::showHighscore(int focusitem) {
   tl->activate();
   tl->freeze();
 
-  playSound("hof.wav");
+  playSound("reversi-hof.wav");
   dlg->exec();
   delete dlg;
 }
@@ -984,10 +1000,10 @@ void App::showHighscore(int focusitem) {
 QString App::getPlayerName() {
   QDialog *dlg = new QDialog(this, "Hall Of Fame", TRUE);
 
-  QLabel  *l1  = new QLabel(locale->translate("You've made in into the \"Hall Of Fame\".Type in\nyour name so mankind will always remember\nyour cool rating."), dlg);
+  QLabel  *l1  = new QLabel(i18n("You've made in into the \"Hall Of Fame\".Type in\nyour name so mankind will always remember\nyour cool rating."), dlg);
   l1->setFixedSize(l1->sizeHint());
 
-  QLabel *l2 = new QLabel(locale->translate("Your name:"), dlg);
+  QLabel *l2 = new QLabel(i18n("Your name:"), dlg);
   l2->setFixedSize(l2->sizeHint());
 
   QLineEdit *e = new QLineEdit(dlg);
@@ -1032,16 +1048,16 @@ QString App::getPlayerName() {
 }
 
 void App::slotBarChanged() {
-  KConfig *conf = kapp->getConfig();
+debug("void App::slotBarChanged()");
+  KConfig *conf = kapp->config();
   if(conf) {
-    conf->writeEntry("Menubar_Pos", (int)(menu->menuBarPos()));
     conf->writeEntry("Toolbar_1_Pos", (int)(tb->barPos()));
   }
 }
 
 void App::saveProperties(KConfig *c) {  
   // make sure options are written
-  kapp->getConfig()->sync();
+  kapp->config()->sync();
   b->saveGame(c);
 }
 
