@@ -40,18 +40,23 @@
 #include "version.h"
 
 #include <kapp.h>
-#include <kmsgbox.h>
 #include <qtimer.h>
 #include <qaccel.h>
 #include <kiconloader.h>
 #include <kseparator.h>
 #include <qlayout.h>
-#include <qmsgbox.h>
+#include <qmessagebox.h>
 #include <debug.h>
 #include <math.h>
+#include <qlineedit.h>
+#include <stdio.h>
+#include <kglobal.h>
+#include <qpushbutton.h>
+#include <kconfig.h>
 
 #define ID_FQUIT	101
 
+#define ID_GFIRST       201
 #define ID_GUNDO	201
 #define ID_GREDO	202
 #define ID_GHOF		203
@@ -59,11 +64,16 @@
 #define ID_GNEW		205
 #define ID_GHINT	206
 #define ID_GISSOLVE	207
+#define ID_GPAUSE       208
+#define ID_GLAST        208
 
 #ifdef DEBUGGING
 #define ID_GFINISH      220
+#undef  ID_GLAST
+#define ID_GLAST        208
 #endif
 
+#define ID_OFIRST       300
 #define ID_OSIZE1	300
 #define ID_OSIZE2	301
 #define ID_OSIZE3	302
@@ -79,6 +89,8 @@
 #define ID_OLVL2	312
 #define ID_OLVL3	313
 #define ID_OSOLVABLE	314
+#define ID_OGRAVITY     315
+#define ID_OLAST        315
 
 #define ID_HTUTORIAL	901
 #define ID_HHELP	900	
@@ -89,9 +101,8 @@ static int DELAY[5] = {125, 250, 500, 750, 1000};
 
 extern int MAX(int, int);
 
-App::App() : KTopLevelWidget() {
-  locale = kapp->getLocale();
-  setCaption(locale->translate("Shisen-Sho"));
+App::App() : KTMainWindow() {
+  setCaption(i18n("Shisen-Sho"));
   readHighscore();
 
   cheat = FALSE;
@@ -99,20 +110,21 @@ App::App() : KTopLevelWidget() {
   // create menu
   mb = new KMenuBar(this);
   QPopupMenu *fm = new QPopupMenu;
-  fm->insertItem(locale->translate("&Quit"), ID_FQUIT);
+  fm->insertItem(i18n("&Quit"), ID_FQUIT);
 
   QPopupMenu *gm = new QPopupMenu;
-  gm->insertItem(locale->translate("&Undo"), ID_GUNDO);
-  gm->insertItem(locale->translate("&Redo"), ID_GREDO);
+  gm->insertItem(i18n("&Undo"), ID_GUNDO);
+  gm->insertItem(i18n("&Redo"), ID_GREDO);
   gm->insertSeparator();
-  gm->insertItem(locale->translate("Get &hint"), ID_GHINT);
+  gm->insertItem(i18n("Get &hint"), ID_GHINT);
   gm->insertSeparator();
-  gm->insertItem(locale->translate("&New game"), ID_GNEW);
-  gm->insertItem(locale->translate("Res&tart game"), ID_GRESTART);
+  gm->insertItem(i18n("&New game"), ID_GNEW);
+  gm->insertItem(i18n("Res&tart game"), ID_GRESTART);
+  gm->insertItem(i18n("&Pause game"), ID_GPAUSE);
   gm->insertSeparator();
-  gm->insertItem(locale->translate("Is game solvable?"), ID_GISSOLVE);
+  gm->insertItem(i18n("Is game solvable?"), ID_GISSOLVE);
   gm->insertSeparator();
-  gm->insertItem(locale->translate("&Hall of Fame"), ID_GHOF);
+  gm->insertItem(i18n("Hall of &Fame"), ID_GHOF);
 #ifdef DEBUGGING
   gm->insertSeparator();
   gm->insertItem("&Finish", ID_GFINISH);
@@ -122,39 +134,39 @@ App::App() : KTopLevelWidget() {
   om->setCheckable(TRUE);
   QPopupMenu *om_s = new QPopupMenu;
   om_s->setCheckable(TRUE);
-  om_s->insertItem(locale->translate("14x6"), ID_OSIZE1);
-  om_s->insertItem(locale->translate("18x8"), ID_OSIZE2);
-  om_s->insertItem(locale->translate("24x12"), ID_OSIZE3);
-  om_s->insertItem(locale->translate("26x14"), ID_OSIZE4);
-  om_s->insertItem(locale->translate("30x16"), ID_OSIZE5);
-  //om_s->insertItem(locale->translate("Custom size..."), ID_OSIZECUSTOM);
+  om_s->insertItem(i18n("14x6"), ID_OSIZE1);
+  om_s->insertItem(i18n("18x8"), ID_OSIZE2);
+  om_s->insertItem(i18n("24x12"), ID_OSIZE3);
+  om_s->insertItem(i18n("26x14"), ID_OSIZE4);
+  om_s->insertItem(i18n("30x16"), ID_OSIZE5);
+  //om_s->insertItem(i18n("Custom size..."), ID_OSIZECUSTOM);
   QPopupMenu *om_sp = new QPopupMenu;
   om_sp->setCheckable(TRUE);
-  om_sp->insertItem(locale->translate("Very fast"), ID_OSPEED1);
-  om_sp->insertItem(locale->translate("Fast"), ID_OSPEED2);
-  om_sp->insertItem(locale->translate("Medium"), ID_OSPEED3);
-  om_sp->insertItem(locale->translate("Slow"), ID_OSPEED4);
-  om_sp->insertItem(locale->translate("Very slow"), ID_OSPEED5);
+  om_sp->insertItem(i18n("Very fast"), ID_OSPEED1);
+  om_sp->insertItem(i18n("Fast"), ID_OSPEED2);
+  om_sp->insertItem(i18n("Medium"), ID_OSPEED3);
+  om_sp->insertItem(i18n("Slow"), ID_OSPEED4);
+  om_sp->insertItem(i18n("Very slow"), ID_OSPEED5);
   QPopupMenu *om_l = new QPopupMenu;
-  om_l->insertItem(locale->translate("Easy"), ID_OLVL1);
-  om_l->insertItem(locale->translate("Medium"), ID_OLVL2);
-  om_l->insertItem(locale->translate("Hard"), ID_OLVL3);
+  om_l->insertItem(i18n("Easy"), ID_OLVL1);
+  om_l->insertItem(i18n("Medium"), ID_OLVL2);
+  om_l->insertItem(i18n("Hard"), ID_OLVL3);
 
-  QPopupMenu *help = kapp->getHelpMenu(true, QString(i18n("Shisen-Sho"))
-                                         + " " + KSHISEN_VERSION
-                                         + i18n("\n\nby Mario Weilguni")
-                                         + " (mweilguni@sime.com)");    
+  QPopupMenu *help = helpMenu(i18n("Shisen-Sho")
+                                    + " " + KSHISEN_VERSION
+                                    + i18n("\n\nby Mario Weilguni")
+                                    + " (mweilguni@sime.com)");
 
-
-  mb->insertItem(locale->translate("&File"), fm);
-  mb->insertItem(locale->translate("&Game"), gm);
-  om->insertItem(locale->translate("Si&ze"), om_s);
-  om->insertItem(locale->translate("S&peed"), om_sp);
-  om->insertItem(locale->translate("&Level"), om_l);
-  om->insertItem(locale->translate("Disallow unsolvable games"), ID_OSOLVABLE);
-  mb->insertItem(locale->translate("&Options"), om);
+  mb->insertItem(i18n("&File"), fm);
+  mb->insertItem(i18n("&Game"), gm);
+  om->insertItem(i18n("Si&ze"), om_s);
+  om->insertItem(i18n("S&peed"), om_sp);
+  om->insertItem(i18n("&Level"), om_l);
+  om->insertItem(i18n("G&ravity"), ID_OGRAVITY);
+  om->insertItem(i18n("Disallow unsolvable games"), ID_OSOLVABLE);
+  mb->insertItem(i18n("&Options"), om);
   mb->insertSeparator();
-  mb->insertItem(locale->translate("&Help"), help);
+  mb->insertItem(i18n("&Help"), help);
 
   mb->setAccel(CTRL+Key_Q, ID_FQUIT);
   mb->setAccel(CTRL+Key_Z, ID_GUNDO);
@@ -172,8 +184,8 @@ App::App() : KTopLevelWidget() {
   b->show();
 
   sb = new KStatusBar(this);
-  sb->insertItem(locale->translate("Your time: XX:XX:XX"), 1);
-  sb->insertItem(locale->translate("Cheat mode"), 2);
+  sb->insertItem(i18n("Your time: XX:XX:XX (XXXXXXXXXXXXXXX)"), 1);
+  sb->insertItem(i18n("Cheat mode"), 2);
   sb->show();
   setStatusBar(sb);
   sb->changeItem("", 2);
@@ -181,15 +193,15 @@ App::App() : KTopLevelWidget() {
   tb = new KToolBar(this);
   connect(tb, SIGNAL(clicked(int)),
 	  this, SLOT(menuCallback(int)));
-  KIconLoader *il = kapp->getIconLoader();
-  tb->insertButton(il->loadIcon("exit.xpm"), 
-		   ID_FQUIT, TRUE, locale->translate("Quit"));
-  tb->insertButton(il->loadIcon("back.xpm"), 
-		   ID_GUNDO, TRUE, locale->translate("Undo"));
-  tb->insertButton(il->loadIcon("forward.xpm"), 
-		   ID_GREDO, TRUE, locale->translate("Redo"));
-  tb->insertButton(il->loadIcon("help.xpm"), 
-		   ID_HHELP, TRUE, locale->translate("Help"));
+
+  tb->insertButton(BarIcon("exit"), 
+		   ID_FQUIT, TRUE, i18n("Quit"));
+  tb->insertButton(BarIcon("back"), 
+		   ID_GUNDO, TRUE, i18n("Undo"));
+  tb->insertButton(BarIcon("forward"), 
+		   ID_GREDO, TRUE, i18n("Redo"));
+  tb->insertButton(BarIcon("help"), 
+		   ID_HHELP, TRUE, i18n("Help"));
   tb->show();
   addToolBar(tb);
   updateRects();
@@ -204,7 +216,7 @@ App::App() : KTopLevelWidget() {
 	  this, SLOT(sizeChanged()));
 
   // load default settings
-  KConfig *conf = kapp->getConfig();
+  KConfig *conf = kapp->config();
   int i;
   i = conf->readNumEntry("Speed", ID_OSPEED3);
   menuCallback(i); // what a hack
@@ -230,6 +242,10 @@ App::App() : KTopLevelWidget() {
   mb->setItemChecked(ID_OSOLVABLE, 
 		     b->getSolvableFlag());
 
+  _b = conf->readNumEntry("Gravity", 1) > 0;
+  b->setGravityFlag(_b);
+  mb->setItemChecked(ID_OGRAVITY, _b);
+
   kapp->processEvents();
   i = conf->readNumEntry("Level", ID_OLVL2);
   menuCallback(i);
@@ -258,19 +274,34 @@ void App::menuCallback(int id) {
     return;
     break;
 
+  case ID_GPAUSE: 
+    {
+      bool paused = b->pause();      
+      lockMenus(paused);
+      if(paused)
+	mb->changeItem(i18n("Resume game"), ID_GPAUSE);
+      else
+	mb->changeItem(i18n("Pause game"), ID_GPAUSE);
+    }
+    break;
+
   case ID_GISSOLVE:
     if(b->solvable())
-      KMsgBox::message(this, locale->translate("Information"),
-		       locale->translate("This game is solveable"));
+	QMessageBox::information(this, i18n("Information"),
+				i18n("This game is solveable"), i18n("OK"));
     else
-      KMsgBox::message(this, locale->translate("Information"),
-		       locale->translate("This game is NOT solveable"));
+	QMessageBox::information(this, i18n("Information"),
+				 i18n("This game is NOT solveable"), i18n("OK"));
     break;
 
   case ID_GHINT:
+#ifdef DEBUGGING
+    b->makeHintMove();
+#else
     b->getHint();
     cheat = TRUE;
-    sb->changeItem(locale->translate("Cheat mode"), 2);
+    sb->changeItem(i18n("Cheat mode"), 2);
+#endif
     break;
 
   case ID_GHOF:
@@ -295,7 +326,7 @@ void App::menuCallback(int id) {
     if(b->canUndo()) {
       b->undo();
       cheat = TRUE;
-      sb->changeItem(locale->translate("Cheat mode"), 2);
+      sb->changeItem(i18n("Cheat mode"), 2);
     }
     break;
 
@@ -312,7 +343,7 @@ void App::menuCallback(int id) {
 
   case ID_OSOLVABLE:
     b->setSolvableFlag(!b->getSolvableFlag());
-    kapp->getConfig()->writeEntry("Solvable", (int)b->getSolvableFlag());
+    kapp->config()->writeEntry("Solvable", (int)b->getSolvableFlag());
     mb->setItemChecked(id, b->getSolvableFlag());
     break;
 
@@ -323,7 +354,7 @@ void App::menuCallback(int id) {
       mb->setItemChecked(i, i == id);
     b->setShuffle((id - ID_OLVL1) * 4 + 1);
     b->newGame();
-    kapp->getConfig()->writeEntry("Level", id);
+    kapp->config()->writeEntry("Level", id);
     break;
    
   case ID_OSIZE1:
@@ -337,7 +368,7 @@ void App::menuCallback(int id) {
       for(i = ID_OSIZE1; i <= ID_OSIZE5; i++)
 	mb->setItemChecked(i, FALSE);
       mb->setItemChecked(id, TRUE);
-      kapp->getConfig()->writeEntry("Size", id);
+      kapp->config()->writeEntry("Size", id);
     }
     break;
 
@@ -360,7 +391,14 @@ void App::menuCallback(int id) {
     break;
 
   case ID_HHELP:
-    KApplication::getKApplication()->invokeHTMLHelp("", ""); 
+    KApplication::kApplication()->invokeHTMLHelp("", ""); 
+    break;
+
+  case ID_OGRAVITY:
+    if(!b->canUndo()) {
+      b->setGravityFlag(!b->gravityFlag());
+      kapp->config()->writeEntry("Gravity", (int)b->gravityFlag());
+    }
     break;
 
   default:
@@ -370,13 +408,28 @@ void App::menuCallback(int id) {
   enableItems();
 }
 
+void App::lockMenus(bool lock) {
+  int i;
+  
+  for(i = ID_GFIRST; i <= ID_GLAST; i++)
+    mb->setItemEnabled(i, !lock | i==ID_GPAUSE);
+  
+  for(i = ID_OFIRST; i <= ID_OLAST; i++)
+    mb->setItemEnabled(i, !lock);
+  enableItems();
+}
+
 void App::enableItems() {
-  mb->setItemEnabled(ID_GUNDO, b->canUndo());
-  mb->setItemEnabled(ID_GREDO, b->canRedo());
-  mb->setItemEnabled(ID_GRESTART, b->canUndo());
-  tb->setItemEnabled(ID_GUNDO, b->canUndo());
-  tb->setItemEnabled(ID_GREDO, b->canRedo());
-  tb->setItemEnabled(ID_GRESTART, b->canUndo());
+  if(!b->isPaused()) {
+    mb->setItemEnabled(ID_GUNDO, b->canUndo());
+    mb->setItemEnabled(ID_GREDO, b->canRedo());
+    mb->setItemEnabled(ID_GRESTART, b->canUndo());
+    tb->setItemEnabled(ID_GUNDO, b->canUndo());
+    tb->setItemEnabled(ID_GREDO, b->canRedo());
+    tb->setItemEnabled(ID_GRESTART, b->canUndo());
+    mb->setItemEnabled(ID_OGRAVITY, !b->canUndo());
+    mb->setItemChecked(ID_OGRAVITY, b->gravityFlag());
+  }
 }
 
 void App::sizeChanged() {
@@ -386,14 +439,16 @@ void App::sizeChanged() {
 
 void App::slotEndOfGame() {
   if(b->tilesLeft() > 0)
-    KMsgBox::message(this, locale->translate("End of game"),
-		     locale->translate("No more moves possible!"));
+      QMessageBox::information(this, i18n("End of game"),
+			       i18n("No more moves possible!"),
+			       i18n("OK"));
   else {
     // create highscore entry
     HighScore hs;
     hs.seconds = b->getTimeForGame();
     hs.x = b->x_tiles();
     hs.y = b->y_tiles();
+    hs.gravity = (int)b->gravityFlag();
 
     // check if we made it into Top10
     bool isHighscore = FALSE;
@@ -413,12 +468,12 @@ void App::slotEndOfGame() {
     } else {
       QString s;
       s.sprintf(
-		locale->translate("Congratulations! You made it in %02d:%02d:%02d"),
+		i18n("Congratulations! You made it in %02d:%02d:%02d"),
 		b->getTimeForGame()/3600,
 		(b->getTimeForGame() / 60)  % 60,
 		b->getTimeForGame() % 60);
       
-      KMsgBox::message(this, locale->translate("End of game"), s.data());
+      QMessageBox::information(this, i18n("End of game"), s, i18n("OK"));
     }
   }
 
@@ -428,23 +483,22 @@ void App::slotEndOfGame() {
 }
 
 void App::updateScore() {
-  QString s;
-  s.sprintf(
-	    locale->translate("Your time: %02d:%02d:%02d"),
-	    b->getTimeForGame()/3600,
-	    (b->getTimeForGame() / 60)  % 60,
-	    b->getTimeForGame() % 60);
+  QString s = i18n("Your time: %1:%2:%3 %4")
+		.arg(QString().sprintf("%02d", b->getTimeForGame()/3600))
+		.arg(QString().sprintf("%02d", (b->getTimeForGame() / 60) % 60))
+		.arg(QString().sprintf("%02d", b->getTimeForGame() % 60))
+		.arg(b->isPaused()?i18n(" (Paused)"):QString::null);
 
-  sb->changeItem(s.data(), 1);
+  sb->changeItem(s, 1);
 }
 
 QString App::getPlayerName() {
   QDialog *dlg = new QDialog(this, "Hall Of Fame", TRUE);
 
-  QLabel  *l1  = new QLabel(locale->translate("You've made in into the \"Hall Of Fame\".Type in\nyour name so mankind will always remember\nyour cool rating."), dlg);
+  QLabel  *l1  = new QLabel(i18n("You've made in into the \"Hall Of Fame\".Type in\nyour name so mankind will always remember\nyour cool rating."), dlg);
   l1->setFixedSize(l1->sizeHint());
 
-  QLabel *l2 = new QLabel(locale->translate("Your name:"), dlg);
+  QLabel *l2 = new QLabel(i18n("Your name:"), dlg);
   l2->setFixedSize(l2->sizeHint());
 
   QLineEdit *e = new QLineEdit(dlg);
@@ -494,7 +548,11 @@ int App::getScore(HighScore &hs) {
   
   double sizebonus = sqrt(ntiles/(double)(14.0 * 6.0));
   double points = tilespersec / 0.14 * 100.0;
-  return (int)(points * sizebonus);
+
+  if(hs.gravity)
+    return (int)(2.0 * points * sizebonus);
+  else
+    return (int)(points * sizebonus);
 }
 
 bool App::isBetter(HighScore &hs, HighScore &than) {
@@ -545,7 +603,7 @@ int App::insertHighscore(HighScore &hs) {
 void App::readHighscore() {
   int i;
   QString s, e, grp;
-  KConfig *conf = kapp->getConfig();
+  KConfig *conf = kapp->config();
 
   highscore.resize(0);
   i = 0;
@@ -555,13 +613,25 @@ void App::readHighscore() {
   while ((i < (int)HIGHSCORE_MAX) && !eol) {
     s.sprintf("Highscore_%d", i);
     if(conf->hasKey(s)) {
-      e = conf->readEntry(s.data());
+      e = conf->readEntry(s);
       highscore.resize(i+1);
 
       HighScore hs;
       memset(hs.name, 0, sizeof(hs.name));
-      sscanf((const char *)e, "%d %d %d %ld %30c",
-	     &hs.x, &hs.y, &hs.seconds, &hs.date, (char*)&hs.name);
+      
+      int nelem;
+      nelem = sscanf((const char *)e, "%d %d %d %ld %d %30c",
+		     &hs.x, &hs.y, &hs.seconds, &hs.date, 
+		     &hs.gravity, (char*)&hs.name);
+    
+      // old version <= 1.1
+      if(nelem == 4) {
+	nelem = sscanf((const char *)e, "%d %d %d %ld %30c",
+		       &hs.x, &hs.y, &hs.seconds, &hs.date, 
+		       (char*)&hs.name);
+	hs.gravity=0;
+      }      
+
       highscore[i] = hs;
     } else
       eol = TRUE;
@@ -580,37 +650,37 @@ void App::readHighscore() {
 //   }
 
   // restore old group
-  conf->setGroup(grp.data());
+  conf->setGroup(grp);
 }
 
 
 void App::writeHighscore() {
   int i;
   QString s, e, grp;
-  KConfig *conf = kapp->getConfig();
+  KConfig *conf = kapp->config();
 
   grp = conf->group();
   conf->setGroup("Hall of Fame");
   for(i = 0; i < (int)highscore.size(); i++) {
     s.sprintf("Highscore_%d", i);
     HighScore hs = highscore[i];
-    e.sprintf("%d %d %d %ld %30s",
-	      hs.x, hs.y, hs.seconds, hs.date, hs.name);
+    e.sprintf("%d %d %d %ld %d %30s",
+	      hs.x, hs.y, hs.seconds, hs.date, hs.gravity, hs.name);
     conf->writeEntry(s, e);
   }
   
   // restore old group
-  conf->setGroup(grp.data());
+  conf->setGroup(grp);
 }
 
 void App::showHighscore(int focusitem)  {
   // this may look a little bit confusing...
-  QDialog *dlg = new QDialog(0, locale->translate("Hall Of Fame"), TRUE);
-  dlg->setCaption(locale->translate("Shisen-Sho: Hall Of Fame"));
+  QDialog *dlg = new QDialog(0, i18n("Hall Of Fame"), TRUE);
+  dlg->setCaption(i18n("Shisen-Sho: Hall Of Fame"));
 
   QVBoxLayout *tl = new QVBoxLayout(dlg, 10);
   
-  QLabel *l = new QLabel(locale->translate("Hall Of Fame"), dlg);
+  QLabel *l = new QLabel(i18n("Hall Of Fame"), dlg);
   QFont f = font();
   f.setPointSize(24);
   f.setBold(TRUE);
@@ -631,25 +701,25 @@ void App::showHighscore(int focusitem)  {
   // add titles
   f = font();
   f.setBold(TRUE);
-  l = new QLabel(locale->translate("Rank"), dlg);
+  l = new QLabel(i18n("Rank"), dlg);
   l->setFont(f);
   l->setMinimumSize(l->sizeHint());
   table->addWidget(l, 0, 0);
-  l = new QLabel(locale->translate("Name"), dlg);
+  l = new QLabel(i18n("Name"), dlg);
   l->setFont(f);
   l->setMinimumSize(l->sizeHint());
   table->addWidget(l, 0, 1);
-  l = new QLabel(locale->translate("Time"), dlg);
+  l = new QLabel(i18n("Time"), dlg);
   l->setFont(f);
   l->setMinimumSize(l->sizeHint());
   table->addWidget(l, 0, 2);
-  l = new QLabel(locale->translate("Size"), dlg);
+  l = new QLabel(i18n("Size"), dlg);
   l->setFont(f);
   l->setMinimumSize(l->sizeHint());
   table->addWidget(l, 0, 3);
-  l = new QLabel(locale->translate("Score"), dlg);
+  l = new QLabel(i18n("Score"), dlg);
   l->setFont(f);
-  l->setMinimumSize(l->sizeHint());
+  l->setMinimumSize(l->sizeHint().width()*3, l->sizeHint().height());
   table->addWidget(l, 0, 4);
   
   QString s;
@@ -663,7 +733,7 @@ void App::showHighscore(int focusitem)  {
     
     // insert rank    
     s.sprintf("%d", i+1);
-    e[i][0] = new QLabel(s.data(), dlg);
+    e[i][0] = new QLabel(s, dlg);
 
     // insert name
     if(i < highscore.size())
@@ -676,7 +746,7 @@ void App::showHighscore(int focusitem)  {
     if(i < highscore.size()) {
       ti = ti.addSecs(hs.seconds);
       s.sprintf("%02d:%02d:%02d", ti.hour(), ti.minute(), ti.second());
-      e[i][2] = new QLabel(s.data(), dlg);
+      e[i][2] = new QLabel(s, dlg);
     } else
       e[i][2] = new QLabel("", dlg);
 
@@ -685,14 +755,16 @@ void App::showHighscore(int focusitem)  {
       s.sprintf("%d x %d", hs.x, hs.y);
     else
       s = "";
-    e[i][3] = new QLabel(s.data(), dlg);
+    e[i][3] = new QLabel(s, dlg);
 
     // insert score
     if(i < highscore.size()) 
-      s.sprintf("%d", getScore(hs));
+      s = QString("%1 %2")
+	.arg(getScore(hs))
+	.arg(hs.gravity ? i18n("(gravity)") : QString(""));
     else
       s = "";
-    e[i][4] = new QLabel(s.data(), dlg);
+    e[i][4] = new QLabel(s, dlg);
     e[i][4]->setAlignment(AlignRight);
   }
 
@@ -711,7 +783,7 @@ void App::showHighscore(int focusitem)  {
       table->addWidget(e[i][j], i+2, j, AlignCenter);	
     }
     
-  QPushButton *b = new QPushButton(locale->translate("Close"), dlg);
+  QPushButton *b = new QPushButton(i18n("Close"), dlg);
   if(style() == MotifStyle)
     b->setFixedSize(b->sizeHint().width() + 10,
 		    b->sizeHint().height() + 10);
