@@ -40,12 +40,11 @@
 #ifndef __APP__H__
 #define __APP__H__
 
-#include "kapp.h"
+#include <ktmainwindow.h>
 #include <ktoolbar.h>
 #include <kstatusbar.h>
 #include <kmenubar.h>
 #include <klocale.h>
-#include <ktopwidget.h>
 #include <time.h>
 #include "board.h"
 
@@ -54,12 +53,14 @@ struct HighScore {
   int  seconds;
   int  x, y;
   time_t date;
+  int gravity;
 };
 
 const unsigned HIGHSCORE_MAX = 10;
 
-class App : public KTopLevelWidget {
+class App : public KTMainWindow {
   Q_OBJECT
+
 public:
   App();
   ~App();
@@ -72,6 +73,7 @@ private slots:
   void updateScore();
 
 private:
+  void lockMenus(bool);
   QString getPlayerName();
   void readHighscore();
   void writeHighscore();
@@ -85,7 +87,6 @@ private:
   KMenuBar *mb;
   KToolBar *tb;
   KStatusBar *sb;
-  KLocale *locale;
   QArray<HighScore> highscore;
   bool cheat;
 };
