@@ -8,6 +8,7 @@
 #include <qlist.h>
 #include <qpixmap.h>
 
+#include <krandomsequence.h>
 
 #include "board.h"
 #include "pixServer.h"
@@ -17,7 +18,7 @@ class Snake : public QObject
     Q_OBJECT
 public:
     Snake(Board *b, PixServer *p, Gate g, PixMap x);
-    Snake::~Snake() {}
+    ~Snake() {}
     void repaint( bool );
     void zero();
 signals:
@@ -39,6 +40,8 @@ protected:
     };
 
     QList<Samy> list;
+    
+    KRandomSequence random;
 
     void reset(int index, int border);
     void appendSamy();
