@@ -1,44 +1,43 @@
 #include <stdlib.h>
 
-#include <qpushbt.h>
+#include <qpushbutton.h>
 #include <qlabel.h>
 #include <qframe.h>
 #include <qpixmap.h>
 #include <qwmatrix.h>
-#include <qdstream.h>
+#include <qdatastream.h>
 #include <qfile.h>
 #include <qstring.h>
 
-#include <kapp.h>
-
 #include "levels.h"
 #include "startroom.h"
 #include "lcdrange.h"
+#include <klocale.h>
 
 
 StartRoom::StartRoom( int init, int *newRoom, QWidget *parent, const char *name)
     : QDialog( parent, name, TRUE )
 {
 
-    setCaption(klocale->translate("Snake Race Starting Room"));
+    setCaption(i18n("Snake Race Starting Room"));
 
     nr = newRoom;
 
     QPushButton *okButton  = new QPushButton(this);
-    okButton->setText(klocale->translate("OK"));
+    okButton->setText(i18n("OK"));
     okButton->setFixedSize(okButton->size());
     okButton->setGeometry(60,170, 100, 100);
     connect( okButton, SIGNAL(clicked()), SLOT(ok()) );
 
     QPushButton *cancelButton  = new QPushButton(this);
-    cancelButton->setText(klocale->translate("Cancel"));
+    cancelButton->setText(i18n("Cancel"));
     connect( cancelButton, SIGNAL(clicked()), SLOT(accept()) );
     cancelButton->setFixedSize(cancelButton->size());
     cancelButton->setGeometry(180,170, 100, 100);
 
     roomRange = new LCDRange(this);
     roomRange->setRange(1, leV->max());
-    roomRange->setText(klocale->translate("Starting Room"));
+    roomRange->setText(i18n("Starting Room"));
     roomRange->setFixedSize(100, 100);
     roomRange->setGeometry(60,30, 115, 125);
 
